@@ -1,5 +1,4 @@
 #!/usr/bin/Rscript --vanilla
-
 is_failure <- function(result) {
     res <- RUnit::getErrors(result)
     names(res) <- tolower(names(res)) # soothe lintr
@@ -14,7 +13,7 @@ if (interactive()) {
     unit_dir <- system.file("inst", "runit_tests", package = "cleanr")
 } else {
     require("cleanr", quietly = TRUE, character.only = TRUE) ||
-        stop("package '", pkgname, "' not found")
+        pkgload::load_all(path = ".") # needed to use pkgload's shim version of
     r_call <- commandArgs(trailingOnly = FALSE)
     if (any(grepl("--file", r_call))) {
         unit_dir <- file.path("inst", "runit_tests")
@@ -31,22 +30,7 @@ package_suite <- RUnit::defineTestSuite("cleanr_unit_test",
                                         testFileRegexp = "^.*\\.[rR]",
                                         testFuncRegexp = "^test_+")
 test_result <- RUnit::runTestSuite(package_suite)
-
-root <- tryCatch(rprojroot::find_root(rprojroot::is_r_package),
-                 error = function(e) return(NULL))
-if (! is.null(root)) {
-    log_dir <- file.path(root, "log")
-    dir.create(log_dir, showWarnings = FALSE)
-    file_name <- file.path(log_dir, "runit.log")
-    html_file <- file.path(log_dir, "runit.html")
-    RUnit::printHTMLProtocol(test_result, fileName = html_file)
-    if (interactive()) {
-        browseURL(paste0("file:", html_file))
-    }
-} else {
-    file_name <- ""
-}
-RUnit::printTextProtocol(test_result, showDetails = TRUE, fileName = file_name)
+RUnit::printTextProtocol(test_result, showDetails = TRUE, fileName = "")
 if (is_failure(test_result)) {
     RUnit::printTextProtocol(test_result, showDetails = TRUE)
     stop("RUnit failed.")
